@@ -5,15 +5,21 @@ import java.util.Date;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionDialog;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionListener;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowsProperties;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ReplaceColumnProgressDialog;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.ReplaceColumnSession;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
@@ -52,9 +58,9 @@ import com.sencha.gxt.widget.core.client.form.TextField;
  * 
  */
 public class ReplacePanel extends FramedPanel implements
-		DimensionRowSelectionListener {
+		DimensionRowSelectionListener, MonitorDialogListener {
 	private DateTimeFormat sdf = DateTimeFormat.getFormat("yyyy-MM-dd");
-	
+
 	protected String WIDTH = "500px";
 	protected String HEIGHT = "150px";
 	protected EventBus eventBus;
@@ -65,7 +71,6 @@ public class ReplacePanel extends FramedPanel implements
 
 	protected DimensionRow dimensionRow;
 
-	
 	protected ReplaceColumnSession replaceColumnSession;
 	private ComboBox<DimensionRow> comboDimensionType;
 	private FieldLabel comboDimensionTypeLabel;
@@ -107,10 +112,22 @@ public class ReplacePanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Error retrieving column: "
-									+ caught.getMessage());
-							UtilsGXT3.alert("Error retrieving column",
-									caught.getMessage());
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("Error retrieving column: "
+											+ caught.getMessage());
+									UtilsGXT3.alert("Error retrieving column",
+											caught.getMessage());
+								}
+							}
 						}
 					}
 
@@ -185,9 +202,11 @@ public class ReplacePanel extends FramedPanel implements
 		HBoxLayoutContainer flowButton = new HBoxLayoutContainer();
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
-
-		flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+		
+		BoxLayoutData boxLayoutData=new BoxLayoutData(new Margins(2, 4, 2, 4));
+		
+		flowButton.add(btnApply, boxLayoutData);
+		flowButton.add(btnClose, boxLayoutData);
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
 		if (column.getDataTypeName().compareTo("Date") == 0) {
@@ -200,7 +219,7 @@ public class ReplacePanel extends FramedPanel implements
 			v.add(new FieldLabel(replaceValue, "Replace"),
 					new VerticalLayoutData(1, -1));
 		}
-		v.add(flowButton, new VerticalLayoutData(-1, 36,
+		v.add(flowButton, new VerticalLayoutData(1, 36,
 				new Margins(5, 2, 5, 2)));
 		add(v);
 
@@ -261,14 +280,15 @@ public class ReplacePanel extends FramedPanel implements
 		HBoxLayoutContainer flowButton = new HBoxLayoutContainer();
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
-
-		flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+		
+		BoxLayoutData boxLayoutData=new BoxLayoutData(new Margins(2, 4, 2, 4));
+		flowButton.add(btnApply, boxLayoutData);
+		flowButton.add(btnClose, boxLayoutData);
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
 		v.add(new FieldLabel(value, "Value"), new VerticalLayoutData(1, -1));
 		v.add(comboDimensionTypeLabel, new VerticalLayoutData(1, -1));
-		v.add(flowButton, new VerticalLayoutData(-1, 36,
+		v.add(flowButton, new VerticalLayoutData(1, 36,
 				new Margins(5, 2, 5, 2)));
 		add(v);
 
@@ -333,7 +353,7 @@ public class ReplacePanel extends FramedPanel implements
 					if (d != null) {
 						String dateS = sdf.format(d);
 						checked = dateS;
-						
+
 					}
 				} else {
 					if (column.getDataTypeName().compareTo("Geometry") == 0) {
@@ -382,12 +402,12 @@ public class ReplacePanel extends FramedPanel implements
 			Log.debug(replaceColumnSession.toString());
 		}
 		TDGWTServiceAsync.INSTANCE.startReplaceColumn(replaceColumnSession,
-				new AsyncCallback<Void>() {
-
+				new AsyncCallback<String>() {
 					@Override
-					public void onSuccess(Void result) {
+					public void onSuccess(String taskId) {
 						Log.debug("Submitted replace column value");
-						callReplaceColumnProgressDialog();
+						openMonitorDialog(taskId);
+
 					}
 
 					@Override
@@ -396,30 +416,32 @@ public class ReplacePanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Error submitting replace column value: "
-									+ caught.getMessage() + " "
-									+ caught.getCause());
-							caught.printStackTrace();
-							UtilsGXT3.alert(
-									"Error submitting replace column value",
-									caught.getMessage());
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("Error submitting replace column value: "
+											+ caught.getMessage()
+											+ " "
+											+ caught.getCause());
+									caught.printStackTrace();
+									UtilsGXT3
+											.alert("Error submitting replace column value",
+													caught.getMessage());
+								}
+							}
 						}
 					}
 				});
 
 	}
 
-	protected void callReplaceColumnProgressDialog() {
-		ReplaceColumnProgressDialog dialog = new ReplaceColumnProgressDialog(
-				parent, eventBus);
-		dialog.show();
-
-	}
-
-	protected void close() {
-		parent.close();
-	}
-
 	protected void addHandlersForComboDimensionType(
 			final LabelProvider<DimensionRow> labelProvider) {
 
@@ -466,4 +488,56 @@ public class ReplacePanel extends FramedPanel implements
 		dimensionRow = null;
 
 	}
+
+	public void close() {
+		if (parent != null) {
+			parent.close();
+		}
+	}
+
+	// /
+	protected void openMonitorDialog(String taskId) {
+		MonitorDialog monitorDialog = new MonitorDialog(taskId, eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.show();
+	}
+
+	@Override
+	public void operationComplete(TRId trId) {
+		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.COLUMNREPLACE, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+	}
+
+	@Override
+	public void operationFailed(Throwable caught, String reason, String details) {
+		UtilsGXT3.alert(reason, details);
+		close();
+
+	}
+
+	@Override
+	public void operationStopped(TRId trId, String reason, String details) {
+		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.COLUMNREPLACE, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+
+	}
+
+	@Override
+	public void operationAborted() {
+		close();
+
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+
+	}
+
 }
